///File : DialogProperty.hpp
//------------------------------------------------------------------------------
/*
    This file is part of DevisMaker.

    DevisMaker is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    DevisMaker is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with DevisMaker.  If not, see <http://www.gnu.org/licenses/>.
*/
//------------------------------------------------------------------------------
#ifndef DIALOG_PROPERTY_HPP_DEVIS_MAKER
#define DIALOG_PROPERTY_HPP_DEVIS_MAKER
//------------------------------------------------------------------------------
#include "wx/wxprec.h"

#ifdef __BORLANDC__
    #pragma hdrstop
#endif

#ifndef WX_PRECOMP
    #include "wx/wx.h"
#endif
//------------------------------------------------------------------------------
#include <wx/notebook.h>
#include <wx/spinctrl.h>
#include <wx/fontpicker.h>
#include <wx/clrpicker.h>
#include <wx/filepicker.h>
#include <wx/statline.h>
//------------------------------------------------------------------------------
#include "config.hpp"
#include "buildVersionOptions.hpp"
//------------------------------------------------------------------------------
#include <DevisManager.hpp>
//------------------------------------------------------------------------------
#include "strWxStdConv.hpp"
#include "findFile.hpp"
//------------------------------------------------------------------------------

struct StructParamCtrl
{
    int type;
    std::string param;
    wxWindow *ctrl;
};
//------------------------------------------------------------------------------
enum{type_check, type_check_enable_next, type_singleLine, type_multiLine, type_double, type_double_per_cent, type_int, type_font, type_color, type_file, type_dir, type_choice_index, type_color_font};
//------------------------------------------------------------------------------
class MyGearsPanel : public wxPanel
{
public:
    MyGearsPanel(wxWindow* parent, wxWindowID id = wxID_ANY, const wxPoint& pos = wxDefaultPosition, const wxSize& size = wxDefaultSize, long style = wxTAB_TRAVERSAL, const wxString& name = _T("panel"));

    void OnPaint(wxPaintEvent& event);

private:
    wxBitmap m_bmp;
};
//------------------------------------------------------------------------------
class MyFontColorPicker : public wxPanel
{
public:
    MyFontColorPicker(wxWindow* parent, wxWindowID id, const wxString &label = _T(""), const StructStdColorFont &data = StructStdColorFont(), const wxPoint& pos = wxDefaultPosition, const wxSize& size = wxDefaultSize, long style = wxDEFAULT_DIALOG_STYLE, const wxString& name = _T("clrFontPicker"));

    void SetStdColorFont(const StructStdColorFont &data);
    StructStdColorFont GetStdColorFont();

    void OnChanged(wxEvent &event);

private:
    wxColourPickerCtrl *m_colorCtrl;
    wxFontPickerCtrl *m_fontCtrl;
};

//------------------------------------------------------------------------------
class DialogProperty : public wxDialog
{
public:
	DialogProperty( wxWindow* parent, wxWindowID id, ConfigManager *cfg, ConfigManager *defaultCfg = NULL, const wxString& title = _T(""), const wxPoint& pos = wxDefaultPosition, const wxSize& size = wxSize( 550, 520 ), long style = wxDEFAULT_DIALOG_STYLE );
    void SaveCfg();
    void LoadCfgForParam(const int &i);
    void LoadCfgForParams();
    void OnModif(wxEvent &event);
    bool IsModified() const;
    void OnEnableNextParam(wxCommandEvent& event);
    void OnDefaultCfg(wxCommandEvent& event);
    void OnReloadCfg(wxCommandEvent& event);

    void RefreshLabels();

    wxNotebook* GetNotebook();

    void AddParamCtrl(const int &type, wxWindow *parent, wxSizer *sizer,const std::string &param, const wxString &label, const void *specialData = NULL);
protected:
    std::vector<StructParamCtrl> m_paramCtrls;

    ConfigManager *m_cfg;
    ConfigManager *m_defaultCfg;

    wxButton *m_undoBt;

    wxNotebook *m_book;

    wxStaticText *m_modifiedLabel;
    bool m_isModified;
    bool m_isSubDialogModified;
};

#endif //DIALOG_PROPERTY_HPP_DEVIS_MAKER
